// -*- C++ -*-
/*!
 * @file  AquesTalk.cpp
 * @brief AquesTalk Component
 * @date $Date$
 *
 * $Id$
 */

#include "AquesTalkRTC.h"

// Module specification
// <rtc-template block="module_spec">
static const char* aquestalk_spec[] =
  {
    "implementation_id", "AquesTalk",
    "type_name",         "AquesTalk",
    "description",       "AquesTalk Component",
    "version",           "1.0.0",
    "vendor",            "ysuga",
    "category",          "Etc",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    //"exec_cxt.periodic.rate", "10.0",
    // Configuration variables
    "conf.default.speed", "100",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
AquesTalk::AquesTalk(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_inIn("in", m_in)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
AquesTalk::~AquesTalk()
{
}



RTC::ReturnCode_t AquesTalk::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  registerInPort("in", m_inIn);
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // Bind variables and configuration variable
  bindParameter("speed", m_speed, "100");
  
  // </rtc-template>
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t AquesTalk::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalk::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalk::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t AquesTalk::onActivated(RTC::UniqueId ec_id)
{
  m_AquesTalkDa = AquesTalkDa_Create();

  return RTC::RTC_OK;
}


RTC::ReturnCode_t AquesTalk::onDeactivated(RTC::UniqueId ec_id)
{
 	AquesTalkDa_Release(m_AquesTalkDa);

	return RTC::RTC_OK;
}


RTC::ReturnCode_t AquesTalk::onExecute(RTC::UniqueId ec_id)
{
	if(this->m_inIn.isNew()) {
		m_inIn.read();
		std::string strbuf = m_in.data;
		//std::cout << ">>> " << strbuf << std::endl;
		int ret = AquesTalkDa_Play(m_AquesTalkDa, 
			strbuf.c_str(), 
		  m_speed);
		if(ret != 0) return RTC::RTC_ERROR;
	}

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t AquesTalk::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalk::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t AquesTalk::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t AquesTalk::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalk::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void AquesTalkRTCInit(RTC::Manager* manager)
  {
	  // Do not remove here
	  std::cout << "This library uses AquesTalk.dll. See http://www.a-quest.com" << std::endl;
	  // Do not remove here

    coil::Properties profile(aquestalk_spec);
    manager->registerFactory(profile,
                             RTC::Create<AquesTalk>,
                             RTC::Delete<AquesTalk>);
  }
  
};


