// -*- C++ -*-
/*!
 * @file  AquesTalkTest.cpp
 * @brief String Out Component
 * @date $Date$
 *
 * $Id$
 */

#include "AquesTalkTest.h"

// Module specification
// <rtc-template block="module_spec">
static const char* aquestalktest_spec[] =
  {
    "implementation_id", "AquesTalkTest",
    "type_name",         "AquesTalkTest",
    "description",       "String Out Component",
    "version",           "1.0.0",
    "vendor",            "ysuga",
    "category",          "Test",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    "exec_cxt.periodic.rate", "10.0",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
AquesTalkTest::AquesTalkTest(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_outOut("out", m_out)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
AquesTalkTest::~AquesTalkTest()
{
}



RTC::ReturnCode_t AquesTalkTest::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  registerOutPort("out", m_outOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t AquesTalkTest::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalkTest::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalkTest::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t AquesTalkTest::onActivated(RTC::UniqueId ec_id)
{
	m_pInputFormController = new CStringInputFormController();
 return RTC::RTC_OK;
}



RTC::ReturnCode_t AquesTalkTest::onDeactivated(RTC::UniqueId ec_id)
{
	m_pInputFormController->stop();
	delete m_pInputFormController;
  return RTC::RTC_OK;
}




RTC::ReturnCode_t AquesTalkTest::onExecute(RTC::UniqueId ec_id)
{
	char strbuf[256];
	
	if(m_pInputFormController->getString(strbuf, 256) > 0) {
		CORBA::String_member str(strbuf);
		m_out.data = str;
		m_outOut.write();
	}
	
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t AquesTalkTest::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalkTest::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalkTest::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalkTest::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t AquesTalkTest::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void AquesTalkTestInit(RTC::Manager* manager)
  {
    coil::Properties profile(aquestalktest_spec);
    manager->registerFactory(profile,
                             RTC::Create<AquesTalkTest>,
                             RTC::Delete<AquesTalkTest>);
  }
  
};


